@@ -1,12 +1,13 @@
 """*Dfetch* can generate output about its working environment."""
 
 import argparse
-import logging
+import platform
 
 import dfetch.commands.command
+from dfetch.log import get_logger
 from dfetch.project import SUPPORTED_PROJECT_TYPES
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class Environment(dfetch.commands.command.Command):
@@ -22,5 +23,6 @@ class Environment(dfetch.commands.command.Command):
 
     def __call__(self, _: argparse.Namespace) -> None:
         """Perform listing the environment."""
+        logger.print_info_line("platform", f"{platform.system()} {platform.release()}")
         for vcs in SUPPORTED_PROJECT_TYPES:
-            vcs.list_tool_info(logger)
+            vcs.list_tool_info()
