@@ -19,7 +19,8 @@ download and a section ``projects:`` that contains a list of projects to fetch.
 """
 import io
 import os
-from typing import IO, Any, Dict, List, Sequence, Tuple, Union
+import pathlib
+from typing import IO, Any, Dict, List, Optional, Sequence, Tuple, Union
 
 import yaml
 from typing_extensions import TypedDict
@@ -29,7 +30,7 @@ from dfetch import DEFAULT_MANIFEST_NAME
 from dfetch.log import get_logger
 from dfetch.manifest.project import ProjectEntry, ProjectEntryDict
 from dfetch.manifest.remote import Remote, RemoteDict
-from dfetch.util.util import find_file
+from dfetch.util.util import find_file, prefix_runtime_exceptions
 
 logger = get_logger(__name__)
 
@@ -61,17 +62,32 @@ class Manifest:
         if not default_remotes:
             default_remotes = list(self._remotes.values())[0:1]
 
-        default_remote = None if not default_remotes else default_remotes[0]
+        self._default_remote = None if not default_remotes else default_remotes[0]
+        self._projects = self._init_projects(manifest["projects"])
 
-        self._projects: Dict[str, ProjectEntry] = {}
-        for project in manifest["projects"]:
+    def _init_projects(
+        self, projects: Sequence[Union[ProjectEntryDict, ProjectEntry, Dict[str, str]]]
+    ) -> Dict[str, ProjectEntry]:
+        """Iterate over projects from manifest and initialize ProjectEntries from it.
+
+        Args:
+            projects (Sequence[Union[ProjectEntryDict, ProjectEntry, Dict[str, str]]]): Iterable with projects
+
+        Raises:
+            RuntimeError: Project unknown
+
+        Returns:
+            Dict[str, ProjectEntry]: Dictionary with key: Name of project, Value: ProjectEntry
+        """
+        _projects: Dict[str, ProjectEntry] = {}
+        for project in projects:
             if isinstance(project, dict):
-                last_project = self._projects[project["name"]] = ProjectEntry.from_yaml(
-                    project, default_remote
+                last_project = _projects[project["name"]] = ProjectEntry.from_yaml(
+                    project, self._default_remote
                 )
             elif isinstance(project, ProjectEntry):
-                last_project = self._projects[project.name] = ProjectEntry.copy(
-                    project, default_remote
+                last_project = _projects[project.name] = ProjectEntry.copy(
+                    project, self._default_remote
                 )
             else:
                 raise RuntimeError(f"{project} has unknown type")
@@ -79,6 +95,8 @@ class Manifest:
             if last_project.remote:
                 last_project.set_remote(self._remotes[last_project.remote])
 
+        return _projects
+
     @staticmethod
     def _determine_remotes(
         remotes_from_manifest: Sequence[Union[RemoteDict, Remote]]
@@ -137,6 +155,11 @@ class Manifest:
         with open(path, "r") as opened_file:
             return Manifest.from_yaml(opened_file)
 
+    def set_parent(self, parent: ProjectEntry) -> None:
+        """Set a parent project for this manifest."""
+        for _, project in self._projects.items():
+            project.set_parent(parent.name)
+
     @property
     def version(self) -> str:
         """Version of the manifest file."""
@@ -190,7 +213,9 @@ def find_manifest() -> str:
     if len(paths) == 0:
         raise RuntimeError("No manifests were found!")
     if len(paths) != 1:
-        raise RuntimeError(f"Multiple manifests found: {paths}")
+        logger.warning(
+            f"Multiple manifests found, using {pathlib.Path(paths[0]).as_posix()}"
+        )
 
     return os.path.realpath(paths[0])
 
@@ -208,6 +233,29 @@ def get_manifest() -> Tuple[Manifest, str]:
     )
 
 
+def get_childmanifests(
+    parent: ProjectEntry, skip: Optional[List[str]] = None
+) -> List[Tuple[Manifest, str]]:
+    """Get manifest and its path."""
+    skip = skip or []
+    logger.debug("Looking for sub-manifests")
+
+    childmanifests = []
+    for path in find_file(DEFAULT_MANIFEST_NAME, "."):
+        path = os.path.realpath(path)
+        if path not in skip:
+            logger.debug(f"Found sub-manifests {path}")
+            with prefix_runtime_exceptions(
+                pathlib.Path(path).relative_to(os.path.dirname(os.getcwd())).as_posix()
+            ):
+                dfetch.manifest.validate.validate(path)
+            childmanifest = dfetch.manifest.manifest.Manifest.from_file(path)
+            childmanifest.set_parent(parent)
+            childmanifests += [(childmanifest, path)]
+
+    return childmanifests
+
+
 class ManifestDumper(yaml.SafeDumper):  # pylint: disable=too-many-ancestors
     """Dump a manifest YAML.
 
