@@ -192,7 +192,9 @@ class GitRepo(VCS):
         if src:
             run_on_cmdline(logger, "git config core.sparsecheckout true")
             with open(".git/info/sparse-checkout", "a") as sparse_checkout_file:
-                sparse_checkout_file.write("/" + src)
+                sparse_checkout_file.write(
+                    "\n".join(["/" + src, "LICENSE*", "COPYING*"])
+                )
 
         run_on_cmdline(logger, f"git fetch --depth 1 origin {version}")
         run_on_cmdline(logger, "git reset --hard FETCH_HEAD")
@@ -205,20 +207,19 @@ class GitRepo(VCS):
     @staticmethod
     def _ls_remote(remote: str) -> Dict[str, str]:
 
-        result = run_on_cmdline(logger, f"git ls-remote {remote}")
+        result = run_on_cmdline(
+            logger, f"git ls-remote --heads --tags {remote}"
+        ).stdout.decode()
 
         info = {}
-        for line in result.stdout.decode().split("\n"):
-            if line:
-                key, value = f"{line} ".split("\t", 1)
-                if not value.startswith("refs/pull"):
+        for line in filter(lambda x: x, result.split("\n")):
+            sha, ref = [part.strip() for part in f"{line} ".split("\t", maxsplit=1)]
 
-                    # Annotated tag commit (more important)
-                    if value.strip().endswith("^{}"):
-                        info[value.strip().strip("^{}")] = key.strip()
-                    else:
-                        if value.strip() not in info:
-                            info[value.strip()] = key.strip()
+            # Annotated tag commit (more important)
+            if ref.endswith("^{}"):
+                info[ref.strip("^{}")] = sha
+            elif ref not in info:
+                info[ref] = sha
         return info
 
     @staticmethod
@@ -234,30 +235,30 @@ class GitRepo(VCS):
 
     @staticmethod
     def _find_branch_in_local_repo_containing_sha(repo_path: str, sha: str) -> str:
-        if not os.path.isdir(repo_path):
+        if not os.path.isdir(os.path.join(repo_path, GitRepo.METADATA_DIR)):
             return ""
 
         with in_directory(repo_path):
-            if not os.path.isdir(GitRepo.METADATA_DIR):
-                return ""
             result = run_on_cmdline(
                 logger,
                 ["git", "branch", "--contains", sha],
             )
 
-        branches: List[str] = []
-        for branch in result.stdout.decode().split("*"):
-            branch = branch.strip()
+        branches: List[str] = [
+            branch.strip()
+            for branch in result.stdout.decode().split("*")
+            if branch.strip() and "HEAD detached at" not in branch.strip()
+        ]
 
-            if branch and "HEAD detached at" not in branch:
-                branches.append(branch)
-
-        return branches[0] if len(branches) == 1 else ""
+        return "" if not branches else branches[0]
 
     @staticmethod
-    def _find_sha_of_branch_or_tag(info: Dict[str, str], branch: str) -> str:
+    def _find_sha_of_branch_or_tag(info: Dict[str, str], branch_or_tag: str) -> str:
         for reference, sha in info.items():
-            if reference in [f"refs/heads/{branch}", f"refs/tags/{branch}"]:
+            if reference in [
+                f"refs/heads/{branch_or_tag}",
+                f"refs/tags/{branch_or_tag}",
+            ]:
                 return sha
         return ""
 
@@ -267,12 +268,11 @@ class GitRepo(VCS):
     ) -> Tuple[str, str]:
         """Check all branch tips and tags and see if the sha is one of them."""
         branch, tag = "", ""
-        info.pop("HEAD", None)
         for reference, sha in info.items():
             if sha.startswith(rev):  # Also allow for shorter SHA's
-                if reference.startswith("refs/heads/"):
-                    branch = reference.replace("refs/heads/", "")
-                elif reference.startswith("refs/tags/"):
+                if reference.startswith("refs/tags/"):
                     tag = reference.replace("refs/tags/", "")
+                elif reference.startswith("refs/heads/"):
+                    branch = reference.replace("refs/heads/", "")
                 break
         return (branch, tag)
